@@ -327,7 +327,7 @@ activate_plugin (GrlRegistry *registry,
                                         grl_plugin_get_id (plugin));
 
   if (!grl_plugin_load (plugin, plugin_configs)) {
-    GRL_WARNING ("Failed to initialize plugin: '%s'", grl_plugin_get_filename (plugin));
+    GRL_DEBUG ("Failed to initialize plugin: '%s'. Check if plugin is well configured", grl_plugin_get_filename (plugin));
     g_set_error (error,
                  GRL_CORE_ERROR,
                  GRL_CORE_ERROR_LOAD_PLUGIN_FAILED,
@@ -784,7 +784,7 @@ grl_registry_load_plugin (GrlRegistry *registry,
 
   module = g_module_open (library_filename, G_MODULE_BIND_LOCAL);
   if (!module) {
-    GRL_WARNING ("Failed to open module: '%s'", library_filename);
+    GRL_WARNING ("Failed to open module: %s", g_module_error ());
     g_set_error (error,
                  GRL_CORE_ERROR,
                  GRL_CORE_ERROR_LOAD_PLUGIN_FAILED,
@@ -1227,6 +1227,7 @@ grl_registry_unload_plugin (GrlRegistry *registry,
 
   if (grl_plugin_get_module (plugin)) {
       g_module_close (grl_plugin_get_module (plugin));
+      grl_plugin_set_module (plugin, NULL);
   }
 
   return TRUE;
